==> radiant_mlhub-0.4.1.tar.gz: radiant_mlhub-0.4.1/README.md <==
[![Radiant MLHub Logo](https://radiant-assets.s3-us-west-2.amazonaws.com/PrimaryRadiantMLHubLogo.png)](https://mlhub.earth/)

# Radiant MLHub Python Client

[![Unit tests](https://github.com/radiantearth/radiant-mlhub/workflows/Unit%20tests/badge.svg)](https://github.com/radiantearth/radiant-mlhub/actions)
[![Documentation](https://readthedocs.org/projects/radiant-mlhub/badge/)](https://radiant-mlhub.readthedocs.io/en/latest/)
[![PyPI version](https://badge.fury.io/py/radiant-mlhub.svg)](https://pypi.org/project/radiant-mlhub/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/radiant-mlhub)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/radiantearth/radiant-mlhub/main?filepath=examples%2Findex.ipynb)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](code_of_conduct.md)

*A Python client for the [Radiant MLHub API](https://mlhub.earth/).*

## Documentation

API reference and Getting Started guides are available on [Read the Docs](https://radiant-mlhub.readthedocs.io/en/latest/).

## Python Version Support

The `radiant_mlhub` Python client requires Python >= 3.7. 

This library aligns with PySTAC in following the recommendations of
[NEP-29](https://numpy.org/neps/nep-0029-deprecation_policy.html) in deprecating support for Python
versions. This means that users can expect support for Python 3.7 to be removed from the `main` branch
after Dec 26, 2021 and therefore from the next release after that date. 

## Design Decisions

Major architectural and design decisions are documented using [Architectural Design Records](https://cognitect.com/blog/2011/11/15/documenting-architecture-decisions) stored in the [`docs/adr`](./docs/adr) directory.

## Contributing

See the [Contributing](./CONTRIBUTING.md) docs for details on contributing to the project.

==> radiant_mlhub-0.5.0.tar.gz: radiant_mlhub-0.5.0/README.md <==
[![Radiant MLHub Logo](https://radiantmlhub.blob.core.windows.net/frontend-misc-assets/radiant_mlhub_white_bg_750.png)](https://mlhub.earth/)

# Radiant MLHub Python Client

[![Unit tests](https://github.com/radiantearth/radiant-mlhub/workflows/Unit%20tests/badge.svg)](https://github.com/radiantearth/radiant-mlhub/actions)
[![Documentation](https://readthedocs.org/projects/radiant-mlhub/badge/)](https://radiant-mlhub.readthedocs.io/en/latest/)
[![PyPI version](https://badge.fury.io/py/radiant-mlhub.svg)](https://pypi.org/project/radiant-mlhub/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/radiant-mlhub)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/radiantearth/radiant-mlhub/main?filepath=examples%2Findex.ipynb)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](code_of_conduct.md)

*A Python client for the [Radiant MLHub API](https://mlhub.earth/).*

## Documentation

API reference and Getting Started guides are available on [Read the Docs](https://radiant-mlhub.readthedocs.io/en/stable/).

## Python Version Support

The `radiant_mlhub` Python client requires Python >= 3.8.

This library aligns with PySTAC in following the recommendations of
[NEP-29](https://numpy.org/neps/nep-0029-deprecation_policy.html) in deprecating support for Python
versions. This means that users can expect support for Python 3.8 to be removed from the `main` branch
after April 14, 2023 and therefore from the next release after that date.

## Design Decisions

Major architectural and design decisions are documented using [Architectural Design Records](https://cognitect.com/blog/2011/11/15/documenting-architecture-decisions) stored in the [`docs/adr`](./docs/adr) directory.

## Contributing

See the [Contributing](./CONTRIBUTING.md) docs for details on contributing to the project.
